/* -----------------------------------------------------------------------------
 *
 * (c) The GHC Team, 1998-2000
 *
 * Prototypes for functions in Disassembler.c
 *
 * ---------------------------------------------------------------------------*/

#ifdef DEBUG

extern int  disInstr   ( StgBCO *bco, int pc );
extern void disassemble( StgBCO *bco );

#endif
